HttpHeaderError

Enum HttpHeaderError 

pub enum HttpHeaderError {
    InvalidFormat(String),
    InvalidUtf8String(Utf8Error),
    InvalidValue(String, String),
    SizeLimitExceeded(String),
    UnsupportedFeature(String, String),
    UnsupportedName(String),
    UnsupportedValue(String, String),
}
Errors associated with a header that is invalid.

Variants



InvalidFormat(String)

The header is misformatted.



InvalidUtf8String(Utf8Error)

The specified header contains illegal characters.



InvalidValue(String, String)

The value specified is not valid.



SizeLimitExceeded(String)

The content length specified is longer than the limit imposed by Micro Http.



UnsupportedFeature(String, String)

The requested feature is not currently supported.



UnsupportedName(String)

The header specified is not supported.



UnsupportedValue(String, String)

The value for the specified header is not supported.