RequestError

Enum RequestError 

pub enum RequestError {
    BodyWithoutPendingRequest,
    HeaderError(HttpHeaderError),
    HeadersWithoutPendingRequest,
    InvalidHttpMethod(&'static str),
    InvalidHttpVersion(&'static str),
    InvalidRequest,
    InvalidUri(&'static str),
    Overflow,
    Underflow,
    SizeLimitExceeded(usize, usize),
}
Errors associated with parsing the HTTP Request from a u8 slice.

Variants



BodyWithoutPendingRequest

No request was pending while the request body was being parsed.



HeaderError(HttpHeaderError)

Header specified is either invalid or not supported by this HTTP implementation.



HeadersWithoutPendingRequest

No request was pending while the request headers were being parsed.



InvalidHttpMethod(&'static str)

The HTTP Method is not supported or it is invalid.



InvalidHttpVersion(&'static str)

The HTTP Version in the Request is not supported or it is invalid.



InvalidRequest

The Request is invalid and cannot be served.



InvalidUri(&'static str)

Request URI is invalid.



Overflow

Overflow occurred when parsing a request.



Underflow

Underflow occurred when parsing a request.



SizeLimitExceeded(usize, usize)

Payload too large.