Response

Struct Response 

pub struct Response { /* private fields */ }
Wrapper over an HTTP Response.

The Response is created using a Version and a StatusCode. When creating a Response object, the body is initialized to None and the header is initialized with the default value. The body can be updated with a call to set_body. The header can be updated with set_content_type and set_server.

Implementations

Source

impl Response

pub fn new(http_version: Version, status_code: StatusCode) -> Self

Creates a new HTTP Response with an empty body.

pub fn set_body(&mut self, body: Body)

Updates the body of the Response.

This function has side effects because it also updates the headers:

  • ContentLength: this is set to the length of the specified body.
pub fn set_content_type(&mut self, content_type: MediaType)

Updates the content type of the Response.

pub fn set_deprecation(&mut self)

Marks the Response as deprecated.

pub fn set_encoding(&mut self)

Updates the encoding type of Response.

pub fn set_server(&mut self, server: &str)

Sets the HTTP response server.

pub fn set_allow(&mut self, methods: Vec<Method>)

Sets the HTTP allowed methods.

pub fn allow_method(&mut self, method: Method)

Allows a specific HTTP method.

pub fn write_all<T: Write>(&self, buf: &mut T) -> Result<(), WriteError>

Writes the content of the Response to the specified buf.

Errors

Returns an error when the buffer is not large enough.

pub fn status(&self) -> StatusCode

Returns the Status Code of the Response.

pub fn body(&self) -> Option<Body>

Returns the Body of the response. If the response does not have a body, it returns None.

pub fn content_length(&self) -> i32

Returns the Content Length of the response.

pub fn content_type(&self) -> MediaType

Returns the Content Type of the response.

pub fn deprecation(&self) -> bool

Returns the deprecation status of the response.

pub fn http_version(&self) -> Version

Returns the HTTP Version of the response.

pub fn allow(&self) -> Vec<Method>

Returns the allowed HTTP methods.