ResponseHeaders

Struct ResponseHeaders 

pub struct ResponseHeaders { /* private fields */ }
Wrapper over the list of headers associated with a HTTP Response. When creating a ResponseHeaders object, the content type is initialized to text/plain. The content type can be updated with a call to set_content_type.

Implementations

Source

impl ResponseHeaders

pub fn write_all<T: Write>(&self, buf: &mut T) -> Result<(), WriteError>

Writes the headers to buf using the HTTP specification.

pub fn set_server(&mut self, server: &str)

Sets the HTTP response header server.

pub fn set_content_type(&mut self, content_type: MediaType)

Sets the content type to be written in the HTTP response.

pub fn set_deprecation(&mut self)

Sets the Deprecation header to be written in the HTTP response. https://tools.ietf.org/id/draft-dalal-deprecation-header-03.html

pub fn set_encoding(&mut self)

Sets the encoding type to be written in the HTTP response.